==> kbibtex-trinity_14.0.4.orig.tar.xz: kbibtex-trinity-14.0.4/src/webquerysciencedirect.h <==
/***************************************************************************
 *   Copyright (C) 2004-2009 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KBIBTEXWEBQUERYSCIENCEDIRECT_H
#define KBIBTEXWEBQUERYSCIENCEDIRECT_H

#include <fileimporterbibtex.h>
#include <webquery.h>

namespace KBibTeX
{
    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryScienceDirectWidget : public WebQueryWidget
    {
        Q_OBJECT
    public:
        WebQueryScienceDirectWidget( TQWidget *parent, const char *name = 0 );

        KLineEdit *lineEditAuthor;
        KLineEdit *lineEditJournal;
        KLineEdit *lineEditVolume;
        KLineEdit *lineEditIssue;
        KLineEdit *lineEditPage;

    protected:
        virtual void init();

    private slots:
        void slotTextChangedSD();
    };


    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryScienceDirect : public WebQuery
    {
        Q_OBJECT
    public:
        WebQueryScienceDirect( TQWidget* parent );
        virtual ~WebQueryScienceDirect();

        void query();

        TQString title();
        TQString disclaimer();
        TQString disclaimerURL();

        WebQueryWidget *widget();

    protected:
        void cancelQuery() { /* nothing */ };

    private:
        BibTeX::FileImporterBibTeX *m_importer;
        WebQueryScienceDirectWidget *m_widget;
        TQString m_incomingData;
        TQString m_md5, m_userid, m_articleListID, m_account;

        bool getStartPage();
        bool getResultPage( const TQString &tak, const TQString &author, const TQString &journal, const TQString &volume, const TQString &issue, const TQString &page );
        bool getArticleListPage();
        bool getRISFile();

    private slots:
        void slotData( TDEIO::Job *job, const TQByteArray &data );
        void slotResult( TDEIO::Job *job );
    };

}

#endif

==> kbibtex-trinity_14.1.0.orig.tar.xz: kbibtex-trinity-14.1.0/src/webquerysciencedirect.h <==
/***************************************************************************
 *   Copyright (C) 2004-2009 by Thomas Fischer                             *
 *   fischer@unix-ag.uni-kl.de                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef KBIBTEXWEBQUERYSCIENCEDIRECT_H
#define KBIBTEXWEBQUERYSCIENCEDIRECT_H

#include "fileimporterbibtex.h"
#include "webquery.h"

namespace KBibTeX
{
    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryScienceDirectWidget : public WebQueryWidget
    {
        Q_OBJECT
    public:
        WebQueryScienceDirectWidget( TQWidget *parent, const char *name = 0 );

        KLineEdit *lineEditAuthor;
        KLineEdit *lineEditJournal;
        KLineEdit *lineEditVolume;
        KLineEdit *lineEditIssue;
        KLineEdit *lineEditPage;

    protected:
        virtual void init();

    private slots:
        void slotTextChangedSD();
    };


    /**
     @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
    */
    class WebQueryScienceDirect : public WebQuery
    {
        Q_OBJECT
    public:
        WebQueryScienceDirect( TQWidget* parent );
        virtual ~WebQueryScienceDirect();

        void query();

        TQString title();
        TQString disclaimer();
        TQString disclaimerURL();

        WebQueryWidget *widget();

    protected:
        void cancelQuery() { /* nothing */ };

    private:
        BibTeX::FileImporterBibTeX *m_importer;
        WebQueryScienceDirectWidget *m_widget;
        TQString m_incomingData;
        TQString m_md5, m_userid, m_articleListID, m_account;

        bool getStartPage();
        bool getResultPage( const TQString &tak, const TQString &author, const TQString &journal, const TQString &volume, const TQString &issue, const TQString &page );
        bool getArticleListPage();
        bool getRISFile();

    private slots:
        void slotData( TDEIO::Job *job, const TQByteArray &data );
        void slotResult( TDEIO::Job *job );
    };

}

#endif
